﻿// ----------------------------------------------------------------------------------
//
// Copyright Microsoft Corporation
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ----------------------------------------------------------------------------------

using System.Collections;
using System.Diagnostics.CodeAnalysis;

namespace Microsoft.WindowsAzure.Management.HDInsight.Cmdlet.DataObjects
{
    /// <summary>
    ///     Structure to contain Hadoop Map-Reduce service configuration.
    /// </summary>
    public class AzureHDInsightMapReduceConfiguration
    {
        /// <summary>
        ///     Initializes a new instance of the AzureHDInsightMapReduceConfiguration class.
        /// </summary>
        public AzureHDInsightMapReduceConfiguration()
        {
            this.Configuration = new Hashtable();
            this.CapacitySchedulerConfiguration = new Hashtable();
        }

        /// <summary>
        ///     Gets or sets the capacity scheduler settings.
        /// </summary>
        [SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly",
            Justification = "Needed for ease of use in Powershell invocation.")]
        public Hashtable CapacitySchedulerConfiguration { get; set; }

        /// <summary>
        ///     Gets or sets the configuration settings.
        /// </summary>
        [SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly",
            Justification = "Needed for ease of use in Powershell invocation.")]
        public Hashtable Configuration { get; set; }
    }
}
